@@ -6,8 +6,8 @@ test_that("Combine two layouts", {
   l2 <- lay_new(matrix(c(1:4),ncol = 2),widths=c(1,1))
   lb <- lay_bind_col(l1,l2, widths = c(2,1))
   
-  expect_equal(lb@widths, c(16, 4, 5, 5))
-  expect_equal(sum(lb@widths[1:2]) / sum(lb@widths[3:4]), 2)
+  expect_equal(lb$widths, c(16, 4, 5, 5))
+  expect_equal(sum(lb$widths[1:2]) / sum(lb$widths[3:4]), 2)
 })
 
 test_that("Check erros in lay_new", {
